# Changelog

## 0.5.0 2021-07-26

- Allow variable types to be a list, e.g. `[String!]`

## 0.4.0 2021-07-23

- Allow '!' after variable type definitions (currently just ignored)

## 0.3.1 2021-07-22

- Allow unused variables to be sent in query

## 0.3.0 2021-07-21

- Support commas as whitespace

## 0.2.0 2021-07-21

- Improve Enum support (was not working properly when wrapped
  in an Optional or List)

## 0.1.1 2021-06-30

- Fix changelog release date + header
- Cosmetic improvements to query parsing

## 0.1.0 2021-06-30

- Initial release
